"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputManifest = exports.produceSourceLine = exports.outputSource = exports.outputLintSummary = exports.outputLintResult = exports.output = void 0;
const screen_1 = require("../../screen");
function output(result, params) {
    var _a, _b;
    params = params !== null && params !== void 0 ? params : {};
    params.skipSummary = (_a = params.skipSummary) !== null && _a !== void 0 ? _a : false;
    params.skipResult = (_b = params.skipResult) !== null && _b !== void 0 ? _b : false;
    if (!result.foundK8sVersion) {
        (0, screen_1.printFailLine)(`Failed to find Kubernetes Version ${result.targetK8sVersion}`);
    }
    else {
        if (!result.foundExactK8sVersion) {
            (0, screen_1.printWarningLine)(`Could not find requested Kubernetes Version: ${result.targetK8sVersion}`);
        }
    }
    (0, screen_1.printInfoLine)(`Linting against Kubernetes Version: ${result.selectedK8sVersion}`);
    (0, screen_1.print)();
    for (const source of result.sources) {
        outputSource(source);
        outputErrors(source, 3);
        for (const manifest of source.manifests) {
            outputManifest(manifest, severityStatusIcon(manifest.severity), 3);
            outputErrors(manifest, 6);
        }
        (0, screen_1.print)();
    }
    (0, screen_1.print)();
    if (!params.skipSummary) {
        outputLintSummary(result);
    }
    if (!params.skipResult) {
        outputLintResult(result);
    }
}
exports.output = output;
function outputLintResult(result) {
    (0, screen_1.printProcessStatus)(result.success, 'Lint');
}
exports.outputLintResult = outputLintResult;
function outputLintSummary(result) {
    (0, screen_1.printSectionTitle)('Lint Summary');
    (0, screen_1.print)(`Sources: ${result.counters.sources.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Sources with Errors', result.counters.sources.withErrors);
    (0, screen_1.print)(`Manifests: ${result.counters.manifests.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.passed, 'Manifests Passed', result.counters.manifests.passed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Manifests with Errors', result.counters.manifests.withErrors);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.warning, 'Manifests With Warnings', result.counters.manifests.withWarnings);
}
exports.outputLintSummary = outputLintSummary;
function outputSource(source, indent) {
    const parts = [];
    parts.push(severityStatusIcon(source.severity).get());
    parts.push(produceSourceLine(source));
    (0, screen_1.print)(parts.join(' '), indent);
}
exports.outputSource = outputSource;
function produceSourceLine(source) {
    const parts = [];
    if (source.kind === 'file') {
        parts.push(screen_1.SOURCE_ICONS.file.get());
    }
    else if (source.kind === 'web') {
        parts.push(screen_1.SOURCE_ICONS.web.get());
    }
    else if (source.kind === 'stream') {
        parts.push(screen_1.SOURCE_ICONS.stream.get());
    }
    else if (source.kind === 'k8s') {
        parts.push(screen_1.SOURCE_ICONS.k8s.get());
    }
    parts.push(`${source.kind.toUpperCase()}:`);
    parts.push(source.path);
    return parts.join(' ');
}
exports.produceSourceLine = produceSourceLine;
function outputManifest(manifest, icon, indent) {
    const namingParts = [];
    if (manifest.namespace) {
        namingParts.push(`Namespace: ${manifest.namespace}`);
    }
    namingParts.push(`API: ${manifest.apiVersion}`);
    namingParts.push(`Kind: ${manifest.kind}`);
    namingParts.push(`Name: ${manifest.name}`);
    const line = namingParts.join(', ');
    (0, screen_1.print)(`${icon.get()} ${line}`, indent);
}
exports.outputManifest = outputManifest;
function outputErrors(obj, indent) {
    if (!obj.success) {
        (0, screen_1.printErrors)(obj.errors, indent);
    }
    (0, screen_1.printWarnings)(obj.warnings, indent);
}
function severityStatusIcon(severity) {
    if (severity === 'pass') {
        return screen_1.STATUS_ICONS.passed;
    }
    else if (severity === 'fail') {
        return screen_1.STATUS_ICONS.failed;
    }
    else if (severity === 'warning') {
        return screen_1.STATUS_ICONS.warning;
    }
    return screen_1.STATUS_ICONS.question;
}
//# sourceMappingURL=output.js.map